@@ -131,7 +131,7 @@ plotResp2 <- function(data, EV, transformation, model, logscale = FALSE,
 
     if (nrow(respPts) >= 250) {
       intervals <- min(c(ceiling(nrow(respPts) / 50), 100))
-      respPts$int <- .reg.interval(respPts[, 1], intervals)
+      respPts$int <- cut(respPts[, 1], max(2, intervals))
       grouped <- dplyr::group_by(respPts, int)
       respLine <- as.data.frame(dplyr::summarise(grouped, n = n(),
         intEV = mean(EV, na.rm = TRUE),
